package com.zehong.system.service;

import java.util.List;
import com.zehong.system.domain.TEnterpriseRankingRisk;

/**
 * 薄弱跟踪Service接口
 * 
 * @author zehong
 * @date 2026-03-17
 */
public interface ITEnterpriseRankingRiskService 
{
    /**
     * 查询薄弱跟踪
     * 
     * @param riskId 薄弱跟踪ID
     * @return 薄弱跟踪
     */
    public TEnterpriseRankingRisk selectTEnterpriseRankingRiskById(Long riskId);

    /**
     * 查询薄弱跟踪列表
     * 
     * @param tEnterpriseRankingRisk 薄弱跟踪
     * @return 薄弱跟踪集合
     */
    public List<TEnterpriseRankingRisk> selectTEnterpriseRankingRiskList(TEnterpriseRankingRisk tEnterpriseRankingRisk);

    /**
     * 新增薄弱跟踪
     * 
     * @param tEnterpriseRankingRisk 薄弱跟踪
     * @return 结果
     */
    public int insertTEnterpriseRankingRisk(TEnterpriseRankingRisk tEnterpriseRankingRisk);

    /**
     * 修改薄弱跟踪
     * 
     * @param tEnterpriseRankingRisk 薄弱跟踪
     * @return 结果
     */
    public int updateTEnterpriseRankingRisk(TEnterpriseRankingRisk tEnterpriseRankingRisk);

    /**
     * 批量删除薄弱跟踪
     * 
     * @param riskIds 需要删除的薄弱跟踪ID
     * @return 结果
     */
    public int deleteTEnterpriseRankingRiskByIds(Long[] riskIds);

    /**
     * 删除薄弱跟踪信息
     * 
     * @param riskId 薄弱跟踪ID
     * @return 结果
     */
    public int deleteTEnterpriseRankingRiskById(Long riskId);
}
